#include "config_file.hpp"
#include <stdlib.h>

sc::config_file::config_file(const std::string& prog_name, bool has_dir)
    : _has_dir {has_dir}, _prog_name {prog_name}
{
    std::string cfg_path;
    _root = getenv("HOME");
    _root += "/.config/";
    if (has_dir) {
        _root += prog_name + "/";
        cfg_path = _root + "config"; // sensible default
                                     // TODO maybe also look for <progname>.conf or <progname>rc here.
    } else {
        cfg_path = _root + prog_name + "rc"; // standard "run control" file
    }
    if (sc::file_exists(cfg_path)) {
        _cfg = sc::parse_ini_file(cfg_path);
    }
}

std::string sc::config_file::path_for_file_name(const std::string& file_name) {
    return _root + file_name;
}

bool sc::config_file::get(const std::string& key, bool default_value) const {
    return get<std::string>(key, default_value ? "yes" : "no") == "yes";
}

std::string sc::config_file::get(const std::string& key,
                                 const std::string& default_value) const {
    auto it = _cfg.find(key);
    if (it == _cfg.end()) {
        return default_value;
    }
    return it->second;
}
