#ifndef SC_CONFIG_HPP_
#define SC_CONFIG_HPP_

#include <string>
#include <map>
#include <libscstring.hpp>

namespace sc {

    class config_file {
        public:
            config_file(const std::string& prog_name, bool has_dir = false);

            std::string path_for_file_name(const std::string& file_name);

            template<typename T>
            T get(const std::string& key, const T& default_value) const {
                auto it = _cfg.find(key);
                if (it == _cfg.end()) {
                    return default_value;
                }
                return sc::from_string<T>(it->second);
            }

            std::string get(const std::string& key,
                            const std::string& default_value) const;
            bool get(const std::string& key, bool default_value) const;

        private:
            bool _has_dir {false};
            std::string _prog_name;
            std::string _root;
            std::map<std::string, std::string> _cfg;
    };

}

#endif // SC_CONFIG_HPP_
